==> openjpa-parent-2.4.3-source-release.zip: openjpa-parent-2.4.3/openjpa-kernel/src/main/java/org/apache/openjpa/kernel/TransientState.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.apache.openjpa.kernel;

/**
 * Lifecycle state.
 * Represents a transient instance; this state lasts only through
 * the {@link #initialize} method, which immediately removes the
 * persistence capable instance from management by the OpenJPA runtime.
 *
 * @author Abe White
 */
@SuppressWarnings("serial")
class TransientState
    extends PCState {

    @Override
    void initialize(StateManagerImpl context, PCState previous) {
        // mark r/w ok, remove from management
        context.unproxyFields();
        context.getPersistenceCapable().pcReplaceStateManager(null);
        context.getBroker().setStateManager(context.getId(),
            context, BrokerImpl.STATUS_TRANSIENT);
    }
    
    public String toString() {
        return "Transient";
    }
}

==> openjpa-parent-4.1.1-source-release.zip: openjpa-parent-4.1.1/openjpa-kernel/src/main/java/org/apache/openjpa/kernel/TransientState.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.openjpa.kernel;

/**
 * Lifecycle state.
 * Represents a transient instance; this state lasts only through
 * the {@link #initialize} method, which immediately removes the
 * persistence capable instance from management by the OpenJPA runtime.
 *
 * @author Abe White
 */
class TransientState extends PCState {
    private static final long serialVersionUID = 1L;

    @Override
    void initialize(StateManagerImpl context, PCState previous) {
        // mark r/w ok, remove from management
        context.unproxyFields();
        context.getPersistenceCapable().pcReplaceStateManager(null);
        context.getBroker().setStateManager(context.getId(),
            context, BrokerImpl.STATUS_TRANSIENT);
    }

    @Override
    public String toString() {
        return "Transient";
    }
}
